@@ -655,12 +655,9 @@ CLI_CHECK_MULTIPLE_WORKERS = -- TODO: need translate!
 CLI_DOC_INITING   = -- TODO: need translate!
 'Loading documents ...'
 CLI_DOC_DONE      = -- TODO: need translate!
-[[
-Document exporting completed!
-Raw data: {}
-Markdown(example): {}
-]]
-
+'Document exporting completed!'
+CLI_DOC_WORKING   =
+'正在產生文件...'
 TYPE_ERROR_ENUM_GLOBAL_DISMATCH = -- TODO: need translate!
 'Type `{child}` cannot match enumeration type of `{parent}`'
 TYPE_ERROR_ENUM_GENERIC_UNSUPPORTED = -- TODO: need translate!
